@@ -4,14 +4,14 @@ import platform
 
 from .code_manager import CodeManager
 from .pygments._mata_builtins import mata_builtins
+from .config import config
 
 
 # NOTE: Add command completion (e.g. r<tab>; mata: st_<tab>)
 # NOTE: Add extended_fcn completions, `:<tab>
 # NOTE: Add sub-command completions for scalars and matrices?
 class CompletionsManager():
-    def __init__(self, kernel, config):
-        self.config = config
+    def __init__(self, kernel):
         self.kernel = kernel
 
         # Path completion
@@ -59,9 +59,12 @@ class CompletionsManager():
             r'(?P<quote>[^\)]*?")'
             r'(?P<pre>[^\)]*?)\Z', flags=re.MULTILINE + re.DOTALL).search
 
-        # Varlist-style matching; applies to all
+        # Varlist-style matching; applies to most
         self.varlist = re.compile(r"(?:\s+)(\S+)", flags=re.MULTILINE)
 
+        # file-style matching
+        self.filelist = re.compile(r"[\r\n]{1,2}", flags=re.MULTILINE)
+
         # Clean line-breaks.
         self.varclean = re.compile(
             r"(?=\s*)[\r\n]{1,2}?^>\s", flags=re.MULTILINE).sub
@@ -87,21 +90,21 @@ class CompletionsManager():
                     r"\([^\)\s]*?\Z", **kwargs).search,
             'line':
                 re.compile(
-                    r"^\s*({0}\s+)*(?P<context>\S+)".format(pre), **kwargs)
-                .search,
+                    r"^\s*({0}\s+)*(?P<context>\S+)".format(pre),
+                    **kwargs).search,
             'delimit_line':
                 re.compile(
-                    r"\A\s*({0}\s+)*(?P<context>\S+)".format(pre), **kwargs)
-                .search}
+                    r"\A\s*({0}\s+)*(?P<context>\S+)".format(pre),
+                    **kwargs).search}
 
         self.suggestions = self.get_suggestions(kernel)
         self.suggestions['magics'] = kernel.magics.available_magics
-        self.suggestions['magics_set'] = kernel.conf.all_settings
+        self.suggestions['magics_set'] = config.all_settings
 
     def refresh(self, kernel):
         self.suggestions = self.get_suggestions(kernel)
         self.suggestions['magics'] = kernel.magics.available_magics
-        self.suggestions['magics_set'] = kernel.conf.all_settings
+        self.suggestions['magics_set'] = config.all_settings
         self.globals = self.get_globals(kernel)
 
     def get_env(self, code, rdelimit, sc_delimit_mode, mata_mode):
@@ -291,7 +294,7 @@ class CompletionsManager():
 
                 pos += posextra
 
-        closing_symbol = self.config.get('autocomplete_closing_symbol', 'False')
+        closing_symbol = config.get('autocomplete_closing_symbol', 'False')
         closing_symbol = closing_symbol.lower() == 'true'
         if not closing_symbol:
             rcomp = ''
@@ -315,8 +318,8 @@ class CompletionsManager():
             return [
                 var for var in self.suggestions['programs']
                 if var.startswith(starts)] + [
-                var for var in self.suggestions['varlist']
-                if var.startswith(starts)] + paths
+                    var for var in self.suggestions['varlist']
+                    if var.startswith(starts)] + paths
         elif env == 1:
             return [
                 var + rcomp
@@ -440,11 +443,16 @@ class CompletionsManager():
         if match:
             suggestions = match.groupdict()
             suggestions['mata'] = self._parse_mata_desc(suggestions['mata'])
-            suggestions['programs'] = self._parse_programs_desc(suggestions['programs'])
+            suggestions['programs'] = self._parse_programs_desc(
+                suggestions['programs'])
             for k, v in suggestions.items():
                 if k in ['mata', 'programs']:
                     continue
-                suggestions[k] = self.varlist.findall(self.varclean('', v))
+                elif k in ['logfiles']:
+                    suggestions[k] = [
+                        f for f in self.filelist.split(v.strip()) if f]
+                else:
+                    suggestions[k] = self.varlist.findall(self.varclean('', v))
 
             all_locals = """mata : invtokens(st_dir("local", "macro", "*")')"""
             res = '\r\n'.join(
@@ -482,7 +490,7 @@ class CompletionsManager():
     def quickdo(self, code, kernel):
         code = kernel.stata._mata_escape(code)
         cm = CodeManager(code)
-        text_to_run, md5, text_to_exclude = cm.get_text(kernel.conf)
+        text_to_run, md5, text_to_exclude = cm.get_text()
         rc, res = kernel.stata.do(
             text_to_run, md5, text_to_exclude=text_to_exclude, display=False)
         return res
@@ -514,7 +522,9 @@ class CompletionsManager():
             items = items[:-1]
 
         # Remove stata-kernel ado files
-        files = ['_StataKernelCompletions', '_StataKernelHead', '_StataKernelLog', '_StataKernelTail']
+        files = [
+            '_StataKernelCompletions', '_StataKernelHead', '_StataKernelLog',
+            '_StataKernelTail']
         items = [x for x in items if x not in files]
 
         # Remove if period in name
